hotspot/test/compiler/unsafe/JdkInternalMiscUnsafeAccessTestShort.java
changeset 40059 c2304140ed64
parent 39419 cc993a4ab581
child 42307 cefc81dc1d52
--- a/hotspot/test/compiler/unsafe/JdkInternalMiscUnsafeAccessTestShort.java	Tue Jul 12 08:42:46 2016 +0000
+++ b/hotspot/test/compiler/unsafe/JdkInternalMiscUnsafeAccessTestShort.java	Tue Jul 12 18:24:48 2016 +0300
@@ -25,13 +25,16 @@
  * @test
  * @bug 8143628
  * @summary Test unsafe access for short
+ *
  * @modules java.base/jdk.internal.misc
  * @run testng/othervm -Diters=100   -Xint                   JdkInternalMiscUnsafeAccessTestShort
  * @run testng/othervm -Diters=20000 -XX:TieredStopAtLevel=1 JdkInternalMiscUnsafeAccessTestShort
  * @run testng/othervm -Diters=20000 -XX:-TieredCompilation  JdkInternalMiscUnsafeAccessTestShort
  * @run testng/othervm -Diters=20000                         JdkInternalMiscUnsafeAccessTestShort
  */
 
+package compiler.unsafe;
+
 import org.testng.annotations.Test;
 
 import java.lang.reflect.Field;
@@ -25,13 +25,16 @@
  * @modules java.base/jdk.internal.misc
- * @run testng/othervm -Diters=100   -Xint                   JdkInternalMiscUnsafeAccessTestShort
- * @run testng/othervm -Diters=20000 -XX:TieredStopAtLevel=1 JdkInternalMiscUnsafeAccessTestShort
- * @run testng/othervm -Diters=20000 -XX:-TieredCompilation  JdkInternalMiscUnsafeAccessTestShort
- * @run testng/othervm -Diters=20000                         JdkInternalMiscUnsafeAccessTestShort
+ * @run testng/othervm -Diters=100   -Xint                   compiler.unsafe.JdkInternalMiscUnsafeAccessTestShort
+ * @run testng/othervm -Diters=20000 -XX:TieredStopAtLevel=1 compiler.unsafe.JdkInternalMiscUnsafeAccessTestShort
+ * @run testng/othervm -Diters=20000 -XX:-TieredCompilation  compiler.unsafe.JdkInternalMiscUnsafeAccessTestShort
+ * @run testng/othervm -Diters=20000                         compiler.unsafe.JdkInternalMiscUnsafeAccessTestShort
  */
 